==> odoo_17.3alpha1.20240508.zip: odoo-17.3a1.post20240508/odoo/addons/website_livechat/static/tests/tours/website_livechat_chatbot_test_page_tour.js <==
import { registry } from "@web/core/registry";
import { contains } from "@web/../tests/utils";

const messagesContain = (text) => `.o-mail-Message:contains("${text}")`;

registry.category("web_tour.tours").add("website_livechat_chatbot_test_page_tour", {
    shadow_dom: ".o-livechat-root",
    steps: () => [
        {
            trigger: messagesContain("Hello! I'm a bot!"),
            async run() {
                const chatWindowContainer = this.anchor.closest(".o-mail-ChatWindowContainer");
                await contains(".o-mail-ChatWindow", {
                    text: "Testing Bot",
                    count: 1,
                    target: chatWindowContainer,
                });
            },
        },
        {
            trigger: messagesContain("I help lost visitors find their way."),
        },
        {
            trigger: messagesContain("How can I help you?"),
        },
        {
            trigger: 'li:contains("I want to buy the software")',
            run: "click",
        },
        {
            trigger: messagesContain("Can you give us your email please?"),
            run() {
                window.location.reload();
            },
        },
        {
            trigger: messagesContain("Hello! I'm a bot!"),
            async run() {
                const chatWindowContainer = this.anchor.closest(".o-mail-ChatWindowContainer");
                await contains(".o-mail-ChatWindow", {
                    text: "Testing Bot",
                    count: 1,
                    target: chatWindowContainer,
                });
            },
        },
    ],
});

==> odoo_18.1alpha1.20241219.zip: odoo-18.1a1.post20241219/odoo/addons/website_livechat/static/tests/tours/website_livechat_chatbot_test_page_tour.js <==
import { registry } from "@web/core/registry";
import { contains } from "@web/../tests/utils";

const messagesContain = (text) => `.o-livechat-root:shadow .o-mail-Message:contains("${text}")`;

registry.category("web_tour.tours").add("website_livechat_chatbot_test_page_tour", {
    steps: () => [
        {
            trigger: messagesContain("Hello! I'm a bot!"),
            async run() {
                const ChatHub = this.anchor.closest(".o-mail-ChatHub");
                await contains(".o-mail-ChatWindow", {
                    text: "Testing Bot",
                    count: 1,
                    target: ChatHub,
                });
            },
        },
        {
            trigger: messagesContain("I help lost visitors find their way."),
            run: "click",
        },
        {
            trigger: messagesContain("How can I help you?"),
            run: "click",
        },
        {
            trigger: '.o-livechat-root:shadow li:contains("I want to buy the software")',
            run: "click",
        },
        {
            trigger: messagesContain("Can you give us your email please?"),
            run() {
                window.location.reload();
            },
        },
        {
            trigger: messagesContain("Hello! I'm a bot!"),
            async run() {
                const ChatHub = this.anchor.closest(".o-mail-ChatHub");
                await contains(".o-mail-ChatWindow", {
                    text: "Testing Bot",
                    count: 1,
                    target: ChatHub,
                });
            },
        },
        {
            trigger: '.o-livechat-root:shadow li:contains("Other & Documentation")',
            run: "click",
        },
        {
            trigger: messagesContain("Please find documentation at"),
            run: () => {},
        },
    ],
});
